This function compute capital stock of provinces in China using the method by Chen (2020).
CompK_CP(
prv,
startyr = 1993,
yr = NULL,
invest = NULL,
InvestPrice = NULL,
depr = NULL,
delta = 0.096,
bt = 1992
)The function return a data.frame, and its 1st column is province, 2nd column is year, 3rd column is capital stock, 4th column is the price index of investment.
a province name, a scalar character. It's Chinese phonetic alphabets.
a numeric scalar. When use the method by Chen (2020), delta is
used before startyr, and after startyr depreciation in data asset is used.
a numeric vector about years. If you only need capital stock before 2017,
you can use its default NULL. If you need to compute capital stocks in other
years (for example 2018,2019), you can set, for example, yr = c(2018,2019).
a numeric vector about investment, its length equal the length of
yr, and its units is 100 million in current price.
a numeric vector about price indices of investment,
its length equal the length of yr, and it is a fixed base index
with equaling 1 in bt.
a numeric vector about depreciation,its length equal the length of yr,
and its units is 100 million in current price.
a rate of depreciation, a scalar number.
a scalar number, such as 2000. It means computing capital stock with its price equal
1 in bt
Chen, Pu, 2020, Compute capital stocks of provinces in China (In Chinese).