This function compute capital stock of provinces in China using the method by Zhang (2008).
CompK_ZJ(
yr = NULL,
invest = NULL,
InvestPrice = NULL,
delta = 0.096,
prv,
bt = 1952
)The function return a data.frame, and its 1st column is province, 2nd column is year, 3rd column is capital stock, 4th column is the price index of investment.
a numeric vector about years. If you only need capital stock before 2017,
you can use its default NULL. If you need to compute capital stocks in other
years (for example 2018,2019), you can set, for example, yr = c(2018,2019).
a numeric vector about investment, its length equal the length of
yr, and its units is 100 million in current price.
a numeric vector about price indices of investment,
its length equal the length of yr, and it is a fixed base index
with equaling 1 in bt.
a rate of depreciation, a scalar number.
a province name, a scalar character. It's Chinese phonetic alphabets.
a scalar number, such as 2000. It means computing capital stock with its price equal
1 in bt
Zhang, J., Estimation of China's provincial capital stock (1952-2004) with applications. Journal of Chinese Economic and Business Studies, 2008. 6(2): p. 177-196.